=======================
ComposeX Modules Syntax
=======================

.. contents::
    :depth: 1

.. include:: ../ecs_composex/COMMON_SYNTAX.rst

.. include:: ../ecs_composex/ecs/SYNTAX.rst

.. include:: ../ecs_composex/compute/SYNTAX.rst

.. include:: ../ecs_composex/sqs/SYNTAX.rst

.. include:: ../ecs_composex/rds/SYNTAX.rst

.. include:: ../ecs_composex/sns/SYNTAX.rst

